@@ -183,7 +183,7 @@ class R3sponse(object):
 		
 		# check file size.
 		size = Formats.FilePath(self.log_file).size(mode="mb", type="integer")
-		if size >= 100: self.reset_logs()
+		if int(size) >= 100: self.reset_logs()
 
 		# return response.
 		return response
